Learn R Programming

mipplot (version 0.3.1)

mipplot_additivity_check: check additivity of rules and data

Description

This function is used for debugging a rule table and data-set. An input is a rule table and a data-set, the outputs are some area plots showing the divergence between the left-side variable and the sum of the right-side variables.

Usage

mipplot_additivity_check(D, R, max_n_plots = Inf, plot_all = FALSE)

Arguments

D

A dataframe of IAMC data in tibble format to produce area plots.

R

A dataframe of data aggregation rules (meta data).

max_n_plots

The maximum number of output plots.

plot_all

set FALSE to plot only inconsistent combinations

Value

A list of area plots.

Examples

Run this code
# NOT RUN {
if (interactive()) {
  mipplot_additivity_check(
    ar5_db_sample_data, ar5_db_sample_rule_table, max_n_plots = 10)
  }
# }

Run the code above in your browser using DataLab