mipplot_additivity_check_bar: Additivity check using bar plot
Description
This function is used for debugging a rule table and data-set.
An input is a rule table and a data-set, the outputs are some bar plots
showing the divergence between the left-side variable and
the sum of the right-side variables.