fill colors automatically
mipplot_autofill_color(rule_table_without_colors)Incomplete color specification rule table. It dosen't contain "Color_code" column.
Complete color specification rule table. It is containing "Color_code" column. However, if color complementation can not be performed automatically, the return value is an incomplete color specification.