Learn R Programming

mipplot (version 0.3.1)

mipplot_read_iamc: Read IAMC scenario input data.

Description

Read scenario input data (in IAMC format) as tibble format dataframe.

Usage

mipplot_read_iamc(
  filename = NULL,
  sep = ",",
  interactive = FALSE,
  DEBUG = TRUE
)

Arguments

filename

Path to a file containing scenario data in IAMC format.

sep

A character indicating the separator used in the input file.

interactive

open a dialog for selecting file if interactive=TRUE.

DEBUG

experimental.

Value

A dataframe in tibble format ("model, scenario, variable, unit, period, value")

Examples

Run this code
# NOT RUN {
mipplot_read_iamc("filename")
# }

Run the code above in your browser using DataLab