Learn R Programming

mipplot (version 0.3.1)

mipplot_read_ruletab: Read file of rule table without ID number

Description

Read table of additivity rule and adds column with id number.

Usage

mipplot_read_ruletab(R_without_id)

Arguments

R_without_id

Path to a file containing data of additivity rule.

Value

A dataframe of additivity rule ("ID, Left_side, Right_side")

Examples

Run this code
# NOT RUN {
mipplot_read_ruletab("filename")
# }

Run the code above in your browser using DataLab