Mutated Table using filtered variable from the rule table
The function arguments include the input dataframes:
The SR15 dataset and the Rule Table and returns a mutated
table with variable, value, model, scenario, region, period
Usage
mipplot_return_table(D, R)
Arguments
D
A dataframe of IAMC data in tibble format to produce mutated table
R
A dataframe of data aggregation rules
Value
Mutated Table of model,scenario,region,variable,unit,period,value