mipplot_additivity_check: check additivity of rules and data
Description
This function is used for debugging a rule table and data-set.
An input is a rule table and a data-set, the outputs are some area plots
showing the divergence between the left-side variable and
the sum of the right-side variables.