powered by
Read table of additivity rule and adds column with id number.
mipplot_read_ruletab(R_without_id)
Path to a file containing data of additivity rule.
A dataframe of additivity rule ("ID, Left_side, Right_side")
# NOT RUN { mipplot_read_ruletab("filename") # }
Run the code above in your browser using DataLab